# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import MessageSender


class SetGroupCallParticipantVolumeLevel(BaseObject):
    """
    Changes a group call participant's volume level. If the current user can manage the group call, then the participant's volume level will be changed for all users with default volume level
    
    Params:
        group_call_id (:class:`int`)
            Group call identifier
        
        participant (:class:`MessageSender`)
            Participant identifier
        
        volume_level (:class:`int`)
            New participant's volume level; 1-20000 in hundreds of percents
        
    """

    ID: str = Field("setGroupCallParticipantVolumeLevel", alias="@type")
    group_call_id: int
    participant: MessageSender
    volume_level: int

    @staticmethod
    def read(q: dict) -> SetGroupCallParticipantVolumeLevel:
        return SetGroupCallParticipantVolumeLevel.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .game_high_score import GameHighScore
from ..base_object import BaseObject


class GameHighScores(BaseObject):
    """
    Contains a list of game high scores
    
    Params:
        scores (:obj:`list[GameHighScore]`)
            A list of game high scores
        
    """

    ID: str = Field("gameHighScores", alias="@type")
    scores: list[GameHighScore]

    @staticmethod
    def read(q: dict) -> GameHighScores:
        return GameHighScores.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetTextEntities(BaseObject):
    """
    Returns all entities (mentions, hashtags, cashtags, bot commands, bank card numbers, URLs, and email addresses) contained in the text. Can be called synchronously
    
    Params:
        text (:class:`str`)
            The text in which to look for entites
        
    """

    ID: str = Field("getTextEntities", alias="@type")
    text: str

    @staticmethod
    def read(q: dict) -> GetTextEntities:
        return GetTextEntities.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class MessageForwardOrigin(BaseObject):
    """
    Contains information about the origin of a forwarded message
    
    """

    ID: str = Field("messageForwardOrigin", alias="@type")


class MessageForwardOriginChannel(MessageForwardOrigin):
    """
    The message was originally a post in a channel
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat from which the message was originally forwarded
        
        message_id (:class:`int`)
            Message identifier of the original message
        
        author_signature (:class:`str`)
            Original post author signature
        
    """

    ID: str = Field("messageForwardOriginChannel", alias="@type")
    chat_id: int
    message_id: int
    author_signature: str

    @staticmethod
    def read(q: dict) -> MessageForwardOriginChannel:
        return MessageForwardOriginChannel.construct(**q)


class MessageForwardOriginChat(MessageForwardOrigin):
    """
    The message was originally sent by an anonymous chat administrator on behalf of the chat
    
    Params:
        sender_chat_id (:class:`int`)
            Identifier of the chat that originally sent the message
        
        author_signature (:class:`str`)
            Original message author signature
        
    """

    ID: str = Field("messageForwardOriginChat", alias="@type")
    sender_chat_id: int
    author_signature: str

    @staticmethod
    def read(q: dict) -> MessageForwardOriginChat:
        return MessageForwardOriginChat.construct(**q)


class MessageForwardOriginHiddenUser(MessageForwardOrigin):
    """
    The message was originally sent by a user, which is hidden by their privacy settings
    
    Params:
        sender_name (:class:`str`)
            Name of the sender
        
    """

    ID: str = Field("messageForwardOriginHiddenUser", alias="@type")
    sender_name: str

    @staticmethod
    def read(q: dict) -> MessageForwardOriginHiddenUser:
        return MessageForwardOriginHiddenUser.construct(**q)


class MessageForwardOriginMessageImport(MessageForwardOrigin):
    """
    The message was imported from an exported message history
    
    Params:
        sender_name (:class:`str`)
            Name of the sender
        
    """

    ID: str = Field("messageForwardOriginMessageImport", alias="@type")
    sender_name: str

    @staticmethod
    def read(q: dict) -> MessageForwardOriginMessageImport:
        return MessageForwardOriginMessageImport.construct(**q)


class MessageForwardOriginUser(MessageForwardOrigin):
    """
    The message was originally sent by a known user
    
    Params:
        sender_user_id (:class:`int`)
            Identifier of the user that originally sent the message
        
    """

    ID: str = Field("messageForwardOriginUser", alias="@type")
    sender_user_id: int

    @staticmethod
    def read(q: dict) -> MessageForwardOriginUser:
        return MessageForwardOriginUser.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .connected_website import ConnectedWebsite
from ..base_object import BaseObject


class ConnectedWebsites(BaseObject):
    """
    Contains a list of websites the current user is logged in with Telegram
    
    Params:
        websites (:obj:`list[ConnectedWebsite]`)
            List of connected websites
        
    """

    ID: str = Field("connectedWebsites", alias="@type")
    websites: list[ConnectedWebsite]

    @staticmethod
    def read(q: dict) -> ConnectedWebsites:
        return ConnectedWebsites.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputMessageContent, MessageSendOptions


class SendMessageAlbum(BaseObject):
    """
    Sends 2-10 messages grouped together into an album. Currently only audio, document, photo and video messages can be grouped into an album. Documents and audio files can be only grouped in an album with messages of the same type. Returns sent messages
    
    Params:
        chat_id (:class:`int`)
            Target chat
        
        message_thread_id (:class:`int`)
            If not 0, a message thread identifier in which the messages will be sent
        
        reply_to_message_id (:class:`int`)
            Identifier of a message to reply to or 0
        
        options (:class:`MessageSendOptions`)
            Options to be used to send the messages
        
        input_message_contents (:obj:`list[InputMessageContent]`)
            Contents of messages to be sent. At most 10 messages can be added to an album
        
    """

    ID: str = Field("sendMessageAlbum", alias="@type")
    chat_id: int
    message_thread_id: int
    reply_to_message_id: int
    options: MessageSendOptions
    input_message_contents: list[InputMessageContent]

    @staticmethod
    def read(q: dict) -> SendMessageAlbum:
        return SendMessageAlbum.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Contact(BaseObject):
    """
    Describes a user contact
    
    Params:
        phone_number (:class:`str`)
            Phone number of the user
        
        first_name (:class:`str`)
            First name of the user; 1-255 characters in length
        
        last_name (:class:`str`)
            Last name of the user
        
        vcard (:class:`str`)
            Additional data about the user in a form of vCard; 0-2048 bytes in length
        
        user_id (:class:`int`)
            Identifier of the user, if known; otherwise 0
        
    """

    ID: str = Field("contact", alias="@type")
    phone_number: str
    first_name: str = Field(..., min_length=1, max_length=255)
    last_name: str
    vcard: str
    user_id: int

    @staticmethod
    def read(q: dict) -> Contact:
        return Contact.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class StorageStatisticsFast(BaseObject):
    """
    Contains approximate storage usage statistics, excluding files of unknown file type
    
    Params:
        files_size (:class:`int`)
            Approximate total size of files
        
        file_count (:class:`int`)
            Approximate number of files
        
        database_size (:class:`int`)
            Size of the database
        
        language_pack_database_size (:class:`int`)
            Size of the language pack database
        
        log_size (:class:`int`)
            Size of the TDLib internal log
        
    """

    ID: str = Field("storageStatisticsFast", alias="@type")
    files_size: int
    file_count: int
    database_size: int
    language_pack_database_size: int
    log_size: int

    @staticmethod
    def read(q: dict) -> StorageStatisticsFast:
        return StorageStatisticsFast.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import TestString


class TestCallVectorStringObject(BaseObject):
    """
    Returns the received vector of objects containing a string; for testing only. This is an offline method. Can be called before authorization
    
    Params:
        x (:obj:`list[TestString]`)
            Vector of objects to return
        
    """

    ID: str = Field("testCallVectorStringObject", alias="@type")
    x: list[TestString]

    @staticmethod
    def read(q: dict) -> TestCallVectorStringObject:
        return TestCallVectorStringObject.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CallbackQueryPayload(BaseObject):
    """
    Represents a payload of a callback query
    
    """

    ID: str = Field("callbackQueryPayload", alias="@type")


class CallbackQueryPayloadData(CallbackQueryPayload):
    """
    The payload for a general callback button
    
    Params:
        data (:class:`str`)
            Data that was attached to the callback button
        
    """

    ID: str = Field("callbackQueryPayloadData", alias="@type")
    data: str

    @staticmethod
    def read(q: dict) -> CallbackQueryPayloadData:
        return CallbackQueryPayloadData.construct(**q)


class CallbackQueryPayloadDataWithPassword(CallbackQueryPayload):
    """
    The payload for a callback button requiring password
    
    Params:
        password (:class:`str`)
            The password for the current user
        
        data (:class:`str`)
            Data that was attached to the callback button
        
    """

    ID: str = Field("callbackQueryPayloadDataWithPassword", alias="@type")
    password: str
    data: str

    @staticmethod
    def read(q: dict) -> CallbackQueryPayloadDataWithPassword:
        return CallbackQueryPayloadDataWithPassword.construct(**q)


class CallbackQueryPayloadGame(CallbackQueryPayload):
    """
    The payload for a game callback button
    
    Params:
        game_short_name (:class:`str`)
            A short name of the game that was attached to the callback button
        
    """

    ID: str = Field("callbackQueryPayloadGame", alias="@type")
    game_short_name: str

    @staticmethod
    def read(q: dict) -> CallbackQueryPayloadGame:
        return CallbackQueryPayloadGame.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DeleteChatReplyMarkup(BaseObject):
    """
    Deletes the default reply markup from a chat. Must be called after a one-time keyboard or a ForceReply reply markup has been used. UpdateChatReplyMarkup will be sent if the reply markup will be changed
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        message_id (:class:`int`)
            The message identifier of the used keyboard
        
    """

    ID: str = Field("deleteChatReplyMarkup", alias="@type")
    chat_id: int
    message_id: int

    @staticmethod
    def read(q: dict) -> DeleteChatReplyMarkup:
        return DeleteChatReplyMarkup.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatMemberStatus


class SetChatMemberStatus(BaseObject):
    """
    Changes the status of a chat member, needs appropriate privileges. This function is currently not suitable for adding new members to the chat and transferring chat ownership; instead, use addChatMember or transferChatOwnership
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        user_id (:class:`int`)
            User identifier
        
        status (:class:`ChatMemberStatus`)
            The new status of the member in the chat
        
    """

    ID: str = Field("setChatMemberStatus", alias="@type")
    chat_id: int
    user_id: int
    status: ChatMemberStatus

    @staticmethod
    def read(q: dict) -> SetChatMemberStatus:
        return SetChatMemberStatus.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from ..base_object import BaseObject
from ..types import Location, ReplyMarkup


class EditMessageLiveLocation(BaseObject):
    """
    Edits the message content of a live location. Messages can be edited for a limited period of time specified in the live location. Returns the edited message after the edit is completed on the server side
    
    Params:
        chat_id (:class:`int`)
            The chat the message belongs to
        
        message_id (:class:`int`)
            Identifier of the message
        
        reply_markup (:class:`ReplyMarkup`)
            The new message reply markup; for bots only
        
        location (:class:`Location`)
            New location content of the message; may be null. Pass null to stop sharing the live location
        
        heading (:class:`int`)
            The new direction in which the location moves, in degrees; 1-360. Pass 0 if unknown
        
        proximity_alert_radius (:class:`int`)
            The new maximum distance for proximity alerts, in meters (0-100000). Pass 0 if the notification is disabled
        
    """

    ID: str = Field("editMessageLiveLocation", alias="@type")
    chat_id: int
    message_id: int
    reply_markup: ReplyMarkup
    location: typing.Optional[Location] = None
    heading: int
    proximity_alert_radius: int

    @staticmethod
    def read(q: dict) -> EditMessageLiveLocation:
        return EditMessageLiveLocation.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Emojis(BaseObject):
    """
    Represents a list of emoji
    
    Params:
        emojis (:obj:`list[str]`)
            List of emojis
        
    """

    ID: str = Field("emojis", alias="@type")
    emojis: list[str]

    @staticmethod
    def read(q: dict) -> Emojis:
        return Emojis.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetFileGenerationProgress(BaseObject):
    """
    Informs TDLib on a file generation progress
    
    Params:
        generation_id (:class:`int`)
            The identifier of the generation process
        
        expected_size (:class:`int`)
            Expected size of the generated file, in bytes; 0 if unknown
        
        local_prefix_size (:class:`int`)
            The number of bytes already generated
        
    """

    ID: str = Field("setFileGenerationProgress", alias="@type")
    generation_id: int
    expected_size: int
    local_prefix_size: int

    @staticmethod
    def read(q: dict) -> SetFileGenerationProgress:
        return SetFileGenerationProgress.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CreateNewBasicGroupChat(BaseObject):
    """
    Creates a new basic group and sends a corresponding messageBasicGroupChatCreate. Returns the newly created chat
    
    Params:
        user_ids (:obj:`list[int]`)
            Identifiers of users to be added to the basic group
        
        title (:class:`str`)
            Title of the new basic group; 1-128 characters
        
    """

    ID: str = Field("createNewBasicGroupChat", alias="@type")
    user_ids: list[int]
    title: str = Field(..., min_length=1, max_length=128)

    @staticmethod
    def read(q: dict) -> CreateNewBasicGroupChat:
        return CreateNewBasicGroupChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .chat_list import ChatList
from .chat_source import ChatSource
from ..base_object import BaseObject


class ChatPosition(BaseObject):
    """
    Describes a position of a chat in a chat list
    
    Params:
        list (:class:`ChatList`)
            The chat list
        
        order (:class:`int`)
            A parameter used to determine order of the chat in the chat list. Chats must be sorted by the pair (order, chat.id) in descending order
        
        is_pinned (:class:`bool`)
            True, if the chat is pinned in the chat list
        
        source (:class:`ChatSource`)
            Source of the chat in the chat list; may be null
        
    """

    ID: str = Field("chatPosition", alias="@type")
    list: ChatList
    order: int
    is_pinned: bool
    source: typing.Optional[ChatSource] = None

    @staticmethod
    def read(q: dict) -> ChatPosition:
        return ChatPosition.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AnswerCustomQuery(BaseObject):
    """
    Answers a custom query; for bots only
    
    Params:
        custom_query_id (:class:`int`)
            Identifier of a custom query
        
        data (:class:`str`)
            JSON-serialized answer to the query
        
    """

    ID: str = Field("answerCustomQuery", alias="@type")
    custom_query_id: int
    data: str

    @staticmethod
    def read(q: dict) -> AnswerCustomQuery:
        return AnswerCustomQuery.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_list import ChatList
from ..base_object import BaseObject


class ChatLists(BaseObject):
    """
    Contains a list of chat lists
    
    Params:
        chat_lists (:obj:`list[ChatList]`)
            List of chat lists
        
    """

    ID: str = Field("chatLists", alias="@type")
    chat_lists: list[ChatList]

    @staticmethod
    def read(q: dict) -> ChatLists:
        return ChatLists.construct(**q)



from collections import Callable, Coroutine
from typing import Any

from aiotdlib.api import BaseObject, MessageText, UpdateNewMessage

FilterCallable = Callable[[BaseObject], Coroutine[Any, Any, bool]]


# Some predefined filters
async def text_message_filter(update: BaseObject):
    return isinstance(update, UpdateNewMessage) and isinstance(update.message.content, MessageText)


def create_bot_command_filter(command: str = None):
    async def bot_command_filter(update: BaseObject) -> bool:
        if not isinstance(update, UpdateNewMessage) or not isinstance(update.message.content, MessageText):
            return False

        message_text = update.message.content.text.text

        if not message_text.startswith('/'):
            return False

        [bot_command, *bot_command_args] = message_text.lstrip('/').split()

        update.EXTRA['bot_command'] = bot_command
        update.EXTRA['bot_command_args'] = bot_command_args

        return not bool(command) or command == bot_command

    return bot_command_filter



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetRepliedMessage(BaseObject):
    """
    Returns information about a message that is replied by a given message. Also returns the pinned message, the game message, and the invoice message for messages of the types messagePinMessage, messageGameScore, and messagePaymentSuccessful respectively
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat the message belongs to
        
        message_id (:class:`int`)
            Identifier of the message reply to which to get
        
    """

    ID: str = Field("getRepliedMessage", alias="@type")
    chat_id: int
    message_id: int

    @staticmethod
    def read(q: dict) -> GetRepliedMessage:
        return GetRepliedMessage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchHashtags(BaseObject):
    """
    Searches for recently used hashtags by their prefix
    
    Params:
        prefix (:class:`str`)
            Hashtag prefix to search for
        
        limit (:class:`int`)
            The maximum number of hashtags to be returned
        
    """

    ID: str = Field("searchHashtags", alias="@type")
    prefix: str
    limit: int

    @staticmethod
    def read(q: dict) -> SearchHashtags:
        return SearchHashtags.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .proxy import Proxy
from ..base_object import BaseObject


class Proxies(BaseObject):
    """
    Represents a list of proxy servers
    
    Params:
        proxies (:obj:`list[Proxy]`)
            List of proxy servers
        
    """

    ID: str = Field("proxies", alias="@type")
    proxies: list[Proxy]

    @staticmethod
    def read(q: dict) -> Proxies:
        return Proxies.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .country_info import CountryInfo
from ..base_object import BaseObject


class Countries(BaseObject):
    """
    Contains information about countries
    
    Params:
        countries (:obj:`list[CountryInfo]`)
            The list of countries
        
    """

    ID: str = Field("countries", alias="@type")
    countries: list[CountryInfo]

    @staticmethod
    def read(q: dict) -> Countries:
        return Countries.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .chat_permissions import ChatPermissions
from ..base_object import BaseObject


class ChatMemberStatus(BaseObject):
    """
    Provides information about the status of a member in a chat
    
    """

    ID: str = Field("chatMemberStatus", alias="@type")


class ChatMemberStatusAdministrator(ChatMemberStatus):
    """
    The user is a member of a chat and has some additional privileges. In basic groups, administrators can edit and delete messages sent by others, add new members, ban unprivileged members, and manage voice chats. In supergroups and channels, there are more detailed options for administrator privileges
    
    Params:
        custom_title (:class:`str`)
            A custom title of the administrator; 0-16 characters without emojis; applicable to supergroups only
        
        can_be_edited (:class:`bool`)
            True, if the current user can edit the administrator privileges for the called user
        
        can_manage_chat (:class:`bool`)
            True, if the administrator can get chat event log, get chat statistics, get message statistics in channels, get channel members, see anonymous administrators in supergroups and ignore slow mode. Implied by any other privilege; applicable to supergroups and channels only
        
        can_change_info (:class:`bool`)
            True, if the administrator can change the chat title, photo, and other settings
        
        can_post_messages (:class:`bool`)
            True, if the administrator can create channel posts; applicable to channels only
        
        can_edit_messages (:class:`bool`)
            True, if the administrator can edit messages of other users and pin messages; applicable to channels only
        
        can_delete_messages (:class:`bool`)
            True, if the administrator can delete messages of other users
        
        can_invite_users (:class:`bool`)
            True, if the administrator can invite new users to the chat
        
        can_restrict_members (:class:`bool`)
            True, if the administrator can restrict, ban, or unban chat members
        
        can_pin_messages (:class:`bool`)
            True, if the administrator can pin messages; applicable to basic groups and supergroups only
        
        can_promote_members (:class:`bool`)
            True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that were directly or indirectly promoted by them
        
        can_manage_voice_chats (:class:`bool`)
            True, if the administrator can manage voice chats
        
        is_anonymous (:class:`bool`)
            True, if the administrator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only
        
    """

    ID: str = Field("chatMemberStatusAdministrator", alias="@type")
    custom_title: typing.Optional[str] = Field(None, max_length=16)
    can_be_edited: bool
    can_manage_chat: bool
    can_change_info: bool
    can_post_messages: bool
    can_edit_messages: bool
    can_delete_messages: bool
    can_invite_users: bool
    can_restrict_members: bool
    can_pin_messages: bool
    can_promote_members: bool
    can_manage_voice_chats: bool
    is_anonymous: bool

    @staticmethod
    def read(q: dict) -> ChatMemberStatusAdministrator:
        return ChatMemberStatusAdministrator.construct(**q)


class ChatMemberStatusBanned(ChatMemberStatus):
    """
    The user was banned (and hence is not a member of the chat). Implies the user can't return to the chat or view messages
    
    Params:
        banned_until_date (:class:`int`)
            Point in time (Unix timestamp) when the user will be unbanned; 0 if never. If the user is banned for more than 366 days or for less than 30 seconds from the current time, the user is considered to be banned forever. Always 0 in basic groups
        
    """

    ID: str = Field("chatMemberStatusBanned", alias="@type")
    banned_until_date: int

    @staticmethod
    def read(q: dict) -> ChatMemberStatusBanned:
        return ChatMemberStatusBanned.construct(**q)


class ChatMemberStatusCreator(ChatMemberStatus):
    """
    The user is the owner of a chat and has all the administrator privileges
    
    Params:
        custom_title (:class:`str`)
            A custom title of the owner; 0-16 characters without emojis; applicable to supergroups only
        
        is_anonymous (:class:`bool`)
            True, if the creator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only
        
        is_member (:class:`bool`)
            True, if the user is a member of the chat
        
    """

    ID: str = Field("chatMemberStatusCreator", alias="@type")
    custom_title: typing.Optional[str] = Field(None, max_length=16)
    is_anonymous: bool
    is_member: bool

    @staticmethod
    def read(q: dict) -> ChatMemberStatusCreator:
        return ChatMemberStatusCreator.construct(**q)


class ChatMemberStatusLeft(ChatMemberStatus):
    """
    The user is not a chat member
    
    """

    ID: str = Field("chatMemberStatusLeft", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatMemberStatusLeft:
        return ChatMemberStatusLeft.construct(**q)


class ChatMemberStatusMember(ChatMemberStatus):
    """
    The user is a member of a chat, without any additional privileges or restrictions
    
    """

    ID: str = Field("chatMemberStatusMember", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatMemberStatusMember:
        return ChatMemberStatusMember.construct(**q)


class ChatMemberStatusRestricted(ChatMemberStatus):
    """
    The user is under certain restrictions in the chat. Not supported in basic groups and channels
    
    Params:
        is_member (:class:`bool`)
            True, if the user is a member of the chat
        
        restricted_until_date (:class:`int`)
            Point in time (Unix timestamp) when restrictions will be lifted from the user; 0 if never. If the user is restricted for more than 366 days or for less than 30 seconds from the current time, the user is considered to be restricted forever
        
        permissions (:class:`ChatPermissions`)
            User permissions in the chat
        
    """

    ID: str = Field("chatMemberStatusRestricted", alias="@type")
    is_member: bool
    restricted_until_date: int
    permissions: ChatPermissions

    @staticmethod
    def read(q: dict) -> ChatMemberStatusRestricted:
        return ChatMemberStatusRestricted.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import MessageSchedulingState


class EditMessageSchedulingState(BaseObject):
    """
    Edits the time when a scheduled message will be sent. Scheduling state of all messages in the same album or forwarded together with the message will be also changed
    
    Params:
        chat_id (:class:`int`)
            The chat the message belongs to
        
        message_id (:class:`int`)
            Identifier of the message
        
        scheduling_state (:class:`MessageSchedulingState`)
            The new message scheduling state. Pass null to send the message immediately
        
    """

    ID: str = Field("editMessageSchedulingState", alias="@type")
    chat_id: int
    message_id: int
    scheduling_state: MessageSchedulingState

    @staticmethod
    def read(q: dict) -> EditMessageSchedulingState:
        return EditMessageSchedulingState.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .vector_path_command import VectorPathCommand
from ..base_object import BaseObject


class ClosedVectorPath(BaseObject):
    """
    Represents a closed vector path. The path begins at the end point of the last command
    
    Params:
        commands (:obj:`list[VectorPathCommand]`)
            List of vector path commands
        
    """

    ID: str = Field("closedVectorPath", alias="@type")
    commands: list[VectorPathCommand]

    @staticmethod
    def read(q: dict) -> ClosedVectorPath:
        return ClosedVectorPath.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import TdlibParameters


class SetTdlibParameters(BaseObject):
    """
    Sets the parameters for TDLib initialization. Works only when the current authorization state is authorizationStateWaitTdlibParameters
    
    Params:
        parameters (:class:`TdlibParameters`)
            Parameters
        
    """

    ID: str = Field("setTdlibParameters", alias="@type")
    parameters: TdlibParameters

    @staticmethod
    def read(q: dict) -> SetTdlibParameters:
        return SetTdlibParameters.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Users(BaseObject):
    """
    Represents a list of users
    
    Params:
        total_count (:class:`int`)
            Approximate total count of users found
        
        user_ids (:obj:`list[int]`)
            A list of user identifiers
        
    """

    ID: str = Field("users", alias="@type")
    total_count: int
    user_ids: list[int]

    @staticmethod
    def read(q: dict) -> Users:
        return Users.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class RevokeChatInviteLink(BaseObject):
    """
    Revokes invite link for a chat. Available for basic groups, supergroups, and channels. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links. If a primary link is revoked, then additionally to the revoked link returns new primary link
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        invite_link (:class:`str`)
            Invite link to be revoked
        
    """

    ID: str = Field("revokeChatInviteLink", alias="@type")
    chat_id: int
    invite_link: str

    @staticmethod
    def read(q: dict) -> RevokeChatInviteLink:
        return RevokeChatInviteLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .text_entity_type import TextEntityType
from ..base_object import BaseObject


class TextEntity(BaseObject):
    """
    Represents a part of the text that needs to be formatted in some unusual way
    
    Params:
        offset (:class:`int`)
            Offset of the entity, in UTF-16 code units
        
        length (:class:`int`)
            Length of the entity, in UTF-16 code units
        
        type_ (:class:`TextEntityType`)
            Type of the entity
        
    """

    ID: str = Field("textEntity", alias="@type")
    offset: int
    length: int
    type_: TextEntityType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> TextEntity:
        return TextEntity.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Count(BaseObject):
    """
    Contains a counter
    
    Params:
        count (:class:`int`)
            Count
        
    """

    ID: str = Field("count", alias="@type")
    count: int

    @staticmethod
    def read(q: dict) -> Count:
        return Count.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_member_status import ChatMemberStatus
from ..base_object import BaseObject


class BasicGroup(BaseObject):
    """
    Represents a basic group of 0-200 users (must be upgraded to a supergroup to accommodate more than 200 users)
    
    Params:
        id (:class:`int`)
            Group identifier
        
        member_count (:class:`int`)
            Number of members in the group
        
        status (:class:`ChatMemberStatus`)
            Status of the current user in the group
        
        is_active (:class:`bool`)
            True, if the group is active
        
        upgraded_to_supergroup_id (:class:`int`)
            Identifier of the supergroup to which this group was upgraded; 0 if none
        
    """

    ID: str = Field("basicGroup", alias="@type")
    id: int
    member_count: int
    status: ChatMemberStatus
    is_active: bool
    upgraded_to_supergroup_id: int

    @staticmethod
    def read(q: dict) -> BasicGroup:
        return BasicGroup.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatAdministrator(BaseObject):
    """
    Contains information about a chat administrator
    
    Params:
        user_id (:class:`int`)
            User identifier of the administrator
        
        custom_title (:class:`str`)
            Custom title of the administrator
        
        is_owner (:class:`bool`)
            True, if the user is the owner of the chat
        
    """

    ID: str = Field("chatAdministrator", alias="@type")
    user_id: int
    custom_title: str
    is_owner: bool

    @staticmethod
    def read(q: dict) -> ChatAdministrator:
        return ChatAdministrator.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TextParseMode(BaseObject):
    """
    Describes the way the text should be parsed for TextEntities
    
    """

    ID: str = Field("textParseMode", alias="@type")


class TextParseModeHTML(TextParseMode):
    """
    The text uses HTML-style formatting. The same as Telegram Bot API "HTML" parse mode
    
    """

    ID: str = Field("textParseModeHTML", alias="@type")

    @staticmethod
    def read(q: dict) -> TextParseModeHTML:
        return TextParseModeHTML.construct(**q)


class TextParseModeMarkdown(TextParseMode):
    """
    The text uses Markdown-style formatting
    
    Params:
        version (:class:`int`)
            Version of the parser: 0 or 1 - Telegram Bot API "Markdown" parse mode, 2 - Telegram Bot API "MarkdownV2" parse mode
        
    """

    ID: str = Field("textParseModeMarkdown", alias="@type")
    version: int

    @staticmethod
    def read(q: dict) -> TextParseModeMarkdown:
        return TextParseModeMarkdown.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .background import Background
from ..base_object import BaseObject


class Backgrounds(BaseObject):
    """
    Contains a list of backgrounds
    
    Params:
        backgrounds (:obj:`list[Background]`)
            A list of backgrounds
        
    """

    ID: str = Field("backgrounds", alias="@type")
    backgrounds: list[Background]

    @staticmethod
    def read(q: dict) -> Backgrounds:
        return Backgrounds.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchEmojis(BaseObject):
    """
    Searches for emojis by keywords. Supported only if the file database is enabled
    
    Params:
        text (:class:`str`)
            Text to search for
        
        exact_match (:class:`bool`)
            True, if only emojis, which exactly match text needs to be returned
        
        input_language_codes (:obj:`list[str]`)
            List of possible IETF language tags of the user's input language; may be empty if unknown
        
    """

    ID: str = Field("searchEmojis", alias="@type")
    text: str
    exact_match: bool
    input_language_codes: list[str]

    @staticmethod
    def read(q: dict) -> SearchEmojis:
        return SearchEmojis.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .inline_query_result import InlineQueryResult
from ..base_object import BaseObject


class InlineQueryResults(BaseObject):
    """
    Represents the results of the inline query. Use sendInlineQueryResultMessage to send the result of the query
    
    Params:
        inline_query_id (:class:`int`)
            Unique identifier of the inline query
        
        next_offset (:class:`str`)
            The offset for the next request. If empty, there are no more results
        
        results (:obj:`list[InlineQueryResult]`)
            Results of the query
        
        switch_pm_text (:class:`str`)
            If non-empty, this text should be shown on the button, which opens a private chat with the bot and sends the bot a start message with the switch_pm_parameter
        
        switch_pm_parameter (:class:`str`)
            Parameter for the bot start message
        
    """

    ID: str = Field("inlineQueryResults", alias="@type")
    inline_query_id: int
    next_offset: str
    results: list[InlineQueryResult]
    switch_pm_text: str
    switch_pm_parameter: str

    @staticmethod
    def read(q: dict) -> InlineQueryResults:
        return InlineQueryResults.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import Contact


class ChangeImportedContacts(BaseObject):
    """
    Changes imported contacts using the list of contacts saved on the device. Imports newly added contacts and, if at least the file database is enabled, deletes recently deleted contacts. Query result depends on the result of the previous query, so only one query is possible at the same time
    
    Params:
        contacts (:obj:`list[Contact]`)
            The new list of contacts, contact's vCard are ignored and are not imported
        
    """

    ID: str = Field("changeImportedContacts", alias="@type")
    contacts: list[Contact]

    @staticmethod
    def read(q: dict) -> ChangeImportedContacts:
        return ChangeImportedContacts.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .authentication_code_info import AuthenticationCodeInfo
from .terms_of_service import TermsOfService
from ..base_object import BaseObject


class AuthorizationState(BaseObject):
    """
    Represents the current authorization state of the TDLib client
    
    """

    ID: str = Field("authorizationState", alias="@type")


class AuthorizationStateClosed(AuthorizationState):
    """
    TDLib client is in its final state. All databases are closed and all resources are released. No other updates will be received after this. All queries will be responded to with error code 500. To continue working, one should create a new instance of the TDLib client
    
    """

    ID: str = Field("authorizationStateClosed", alias="@type")

    @staticmethod
    def read(q: dict) -> AuthorizationStateClosed:
        return AuthorizationStateClosed.construct(**q)


class AuthorizationStateClosing(AuthorizationState):
    """
    TDLib is closing, all subsequent queries will be answered with the error 500. Note that closing TDLib can take a while. All resources will be freed only after authorizationStateClosed has been received
    
    """

    ID: str = Field("authorizationStateClosing", alias="@type")

    @staticmethod
    def read(q: dict) -> AuthorizationStateClosing:
        return AuthorizationStateClosing.construct(**q)


class AuthorizationStateLoggingOut(AuthorizationState):
    """
    The user is currently logging out
    
    """

    ID: str = Field("authorizationStateLoggingOut", alias="@type")

    @staticmethod
    def read(q: dict) -> AuthorizationStateLoggingOut:
        return AuthorizationStateLoggingOut.construct(**q)


class AuthorizationStateReady(AuthorizationState):
    """
    The user has been successfully authorized. TDLib is now ready to answer queries
    
    """

    ID: str = Field("authorizationStateReady", alias="@type")

    @staticmethod
    def read(q: dict) -> AuthorizationStateReady:
        return AuthorizationStateReady.construct(**q)


class AuthorizationStateWaitCode(AuthorizationState):
    """
    TDLib needs the user's authentication code to authorize
    
    Params:
        code_info (:class:`AuthenticationCodeInfo`)
            Information about the authorization code that was sent
        
    """

    ID: str = Field("authorizationStateWaitCode", alias="@type")
    code_info: AuthenticationCodeInfo

    @staticmethod
    def read(q: dict) -> AuthorizationStateWaitCode:
        return AuthorizationStateWaitCode.construct(**q)


class AuthorizationStateWaitEncryptionKey(AuthorizationState):
    """
    TDLib needs an encryption key to decrypt the local database
    
    Params:
        is_encrypted (:class:`bool`)
            True, if the database is currently encrypted
        
    """

    ID: str = Field("authorizationStateWaitEncryptionKey", alias="@type")
    is_encrypted: bool

    @staticmethod
    def read(q: dict) -> AuthorizationStateWaitEncryptionKey:
        return AuthorizationStateWaitEncryptionKey.construct(**q)


class AuthorizationStateWaitOtherDeviceConfirmation(AuthorizationState):
    """
    The user needs to confirm authorization on another logged in device by scanning a QR code with the provided link
    
    Params:
        link (:class:`str`)
            A tg:// URL for the QR code. The link will be updated frequently
        
    """

    ID: str = Field("authorizationStateWaitOtherDeviceConfirmation", alias="@type")
    link: str

    @staticmethod
    def read(q: dict) -> AuthorizationStateWaitOtherDeviceConfirmation:
        return AuthorizationStateWaitOtherDeviceConfirmation.construct(**q)


class AuthorizationStateWaitPassword(AuthorizationState):
    """
    The user has been authorized, but needs to enter a password to start using the application
    
    Params:
        password_hint (:class:`str`)
            Hint for the password; may be empty
        
        has_recovery_email_address (:class:`bool`)
            True, if a recovery email address has been set up
        
        recovery_email_address_pattern (:class:`str`)
            Pattern of the email address to which the recovery email was sent; empty until a recovery email has been sent
        
    """

    ID: str = Field("authorizationStateWaitPassword", alias="@type")
    password_hint: str
    has_recovery_email_address: bool
    recovery_email_address_pattern: str

    @staticmethod
    def read(q: dict) -> AuthorizationStateWaitPassword:
        return AuthorizationStateWaitPassword.construct(**q)


class AuthorizationStateWaitPhoneNumber(AuthorizationState):
    """
    TDLib needs the user's phone number to authorize. Call `setAuthenticationPhoneNumber` to provide the phone number, or use `requestQrCodeAuthentication`, or `checkAuthenticationBotToken` for other authentication options
    
    """

    ID: str = Field("authorizationStateWaitPhoneNumber", alias="@type")

    @staticmethod
    def read(q: dict) -> AuthorizationStateWaitPhoneNumber:
        return AuthorizationStateWaitPhoneNumber.construct(**q)


class AuthorizationStateWaitRegistration(AuthorizationState):
    """
    The user is unregistered and need to accept terms of service and enter their first name and last name to finish registration
    
    Params:
        terms_of_service (:class:`TermsOfService`)
            Telegram terms of service
        
    """

    ID: str = Field("authorizationStateWaitRegistration", alias="@type")
    terms_of_service: TermsOfService

    @staticmethod
    def read(q: dict) -> AuthorizationStateWaitRegistration:
        return AuthorizationStateWaitRegistration.construct(**q)


class AuthorizationStateWaitTdlibParameters(AuthorizationState):
    """
    TDLib needs TdlibParameters for initialization
    
    """

    ID: str = Field("authorizationStateWaitTdlibParameters", alias="@type")

    @staticmethod
    def read(q: dict) -> AuthorizationStateWaitTdlibParameters:
        return AuthorizationStateWaitTdlibParameters.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatStatisticsMessageInteractionInfo(BaseObject):
    """
    Contains statistics about interactions with a message
    
    Params:
        message_id (:class:`int`)
            Message identifier
        
        view_count (:class:`int`)
            Number of times the message was viewed
        
        forward_count (:class:`int`)
            Number of times the message was forwarded
        
    """

    ID: str = Field("chatStatisticsMessageInteractionInfo", alias="@type")
    message_id: int
    view_count: int
    forward_count: int

    @staticmethod
    def read(q: dict) -> ChatStatisticsMessageInteractionInfo:
        return ChatStatisticsMessageInteractionInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class BlockMessageSenderFromReplies(BaseObject):
    """
    Blocks an original sender of a message in the Replies chat
    
    Params:
        message_id (:class:`int`)
            The identifier of an incoming message in the Replies chat
        
        delete_message (:class:`bool`)
            Pass true if the message must be deleted
        
        delete_all_messages (:class:`bool`)
            Pass true if all messages from the same sender must be deleted
        
        report_spam (:class:`bool`)
            Pass true if the sender must be reported to the Telegram moderators
        
    """

    ID: str = Field("blockMessageSenderFromReplies", alias="@type")
    message_id: int
    delete_message: bool
    delete_all_messages: bool
    report_spam: bool

    @staticmethod
    def read(q: dict) -> BlockMessageSenderFromReplies:
        return BlockMessageSenderFromReplies.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatStatisticsAdministratorActionsInfo(BaseObject):
    """
    Contains statistics about administrator actions done by a user
    
    Params:
        user_id (:class:`int`)
            Administrator user identifier
        
        deleted_message_count (:class:`int`)
            Number of messages deleted by the administrator
        
        banned_user_count (:class:`int`)
            Number of users banned by the administrator
        
        restricted_user_count (:class:`int`)
            Number of users restricted by the administrator
        
    """

    ID: str = Field("chatStatisticsAdministratorActionsInfo", alias="@type")
    user_id: int
    deleted_message_count: int
    banned_user_count: int
    restricted_user_count: int

    @staticmethod
    def read(q: dict) -> ChatStatisticsAdministratorActionsInfo:
        return ChatStatisticsAdministratorActionsInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetArchivedStickerSets(BaseObject):
    """
    Returns a list of archived sticker sets
    
    Params:
        is_masks (:class:`bool`)
            Pass true to return mask stickers sets; pass false to return ordinary sticker sets
        
        offset_sticker_set_id (:class:`int`)
            Identifier of the sticker set from which to return the result
        
        limit (:class:`int`)
            The maximum number of sticker sets to return
        
    """

    ID: str = Field("getArchivedStickerSets", alias="@type")
    is_masks: bool
    offset_sticker_set_id: int
    limit: int

    @staticmethod
    def read(q: dict) -> GetArchivedStickerSets:
        return GetArchivedStickerSets.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import SearchMessagesFilter


class GetChatMessageCount(BaseObject):
    """
    Returns approximate number of messages of the specified type in the chat
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat in which to count messages
        
        filter_ (:class:`SearchMessagesFilter`)
            Filter for message content; searchMessagesFilterEmpty is unsupported in this function
        
        return_local (:class:`bool`)
            If true, returns count that is available locally without sending network requests, returning -1 if the number of messages is unknown
        
    """

    ID: str = Field("getChatMessageCount", alias="@type")
    chat_id: int
    filter_: SearchMessagesFilter = Field(..., alias='filter')
    return_local: bool

    @staticmethod
    def read(q: dict) -> GetChatMessageCount:
        return GetChatMessageCount.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetBotUpdatesStatus(BaseObject):
    """
    Informs the server about the number of pending bot updates if they haven't been processed for a long time; for bots only
    
    Params:
        pending_update_count (:class:`int`)
            The number of pending updates
        
        error_message (:class:`str`)
            The last error message
        
    """

    ID: str = Field("setBotUpdatesStatus", alias="@type")
    pending_update_count: int
    error_message: str

    @staticmethod
    def read(q: dict) -> SetBotUpdatesStatus:
        return SetBotUpdatesStatus.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TemporaryPasswordState(BaseObject):
    """
    Returns information about the availability of a temporary password, which can be used for payments
    
    Params:
        has_password (:class:`bool`)
            True, if a temporary password is available
        
        valid_for (:class:`int`)
            Time left before the temporary password expires, in seconds
        
    """

    ID: str = Field("temporaryPasswordState", alias="@type")
    has_password: bool
    valid_for: int

    @staticmethod
    def read(q: dict) -> TemporaryPasswordState:
        return TemporaryPasswordState.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .input_file import InputFile
from .mask_position import MaskPosition
from ..base_object import BaseObject


class InputSticker(BaseObject):
    """
    Describes a sticker that needs to be added to a sticker set
    
    """

    ID: str = Field("inputSticker", alias="@type")


class InputStickerAnimated(InputSticker):
    """
    An animated sticker in TGS format
    
    Params:
        sticker (:class:`InputFile`)
            File with the animated sticker. Only local or uploaded within a week files are supported. See https://core.telegram.org/animated_stickers#technical-requirements for technical requirements
        
        emojis (:class:`str`)
            Emojis corresponding to the sticker
        
    """

    ID: str = Field("inputStickerAnimated", alias="@type")
    sticker: InputFile
    emojis: str

    @staticmethod
    def read(q: dict) -> InputStickerAnimated:
        return InputStickerAnimated.construct(**q)


class InputStickerStatic(InputSticker):
    """
    A static sticker in PNG format, which will be converted to WEBP server-side
    
    Params:
        sticker (:class:`InputFile`)
            PNG image with the sticker; must be up to 512 KB in size and fit in a 512x512 square
        
        emojis (:class:`str`)
            Emojis corresponding to the sticker
        
        mask_position (:class:`MaskPosition`)
            For masks, position where the mask should be placed; may be null
        
    """

    ID: str = Field("inputStickerStatic", alias="@type")
    sticker: InputFile
    emojis: str
    mask_position: typing.Optional[MaskPosition] = None

    @staticmethod
    def read(q: dict) -> InputStickerStatic:
        return InputStickerStatic.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ResendAuthenticationCode(BaseObject):
    """
    Re-sends an authentication code to the user. Works only when the current authorization state is authorizationStateWaitCode and the next_code_type of the result is not null
    
    """

    ID: str = Field("resendAuthenticationCode", alias="@type")

    @staticmethod
    def read(q: dict) -> ResendAuthenticationCode:
        return ResendAuthenticationCode.construct(**q)



from __future__ import annotations

import re
import typing

from pydantic import BaseModel, validator

from .utils import lower_first, snake_case, upper_first

vector_type_regex = re.compile(r"vector<(?P<type>.*)>")
list_type_regex = re.compile(r".*list\[(?P<type>\w+)].*")
core_types = {
    'int': 'int', 'int32': 'int', 'int53': 'int', 'int64': 'int', 'long': 'int', 'double': 'float',
    'Double': 'float',
    'float': 'float',
    'Int': 'int',
    'string': 'str',
    'str': 'str',
    'Str': 'str',
    'String': 'str',
    'bool': 'bool',
    'boolFalse': 'bool',
    'boolTrue': 'bool',
    'Bool': 'bool',
    # Bytes in TDLib should be encoded as base64, so they should be stored as str
    'bytes': 'str',
    'Bytes': 'str',
}


class BaseType(BaseModel):
    name: str

    @property
    def snake_name(self) -> str:
        return snake_case(self.name)

    @property
    def lf_name(self) -> str:
        """
        lf - abbreviation of Lower_First
        """
        return lower_first(self.name)

    @property
    def uf_name(self) -> str:
        """
        uf - abbreviation of Upper_First
        """
        return upper_first(self.name)


class Parameter(BaseModel):
    # Optional constraints
    nullable: bool = False
    min_length: typing.Optional[int] = None
    max_length: typing.Optional[int] = None

    type: str
    name: str
    alias: str = None
    doc: str = ""

    @validator('name')
    def check_name(cls, name):
        if name in ['json', 'filter', 'type', 'hash']:
            return f"{name}_"

        return name

    @validator('alias', always=True)
    def set_alias(cls, _, values):
        name = values.get('name').rstrip('_')

        if name in ['json', 'filter', 'type', 'hash']:
            return name

        return None

    @validator('type', pre=True)
    def convert_tl_type(cls, tl_type: str) -> str:
        if not tl_type:
            return ""

        if tl_type in core_types:
            return core_types[tl_type]

        vector_type_match = vector_type_regex.match(tl_type)

        if vector_type_match:
            return f"list[{cls.convert_tl_type(vector_type_match.group('type'))}]"

        return upper_first(tl_type)

    @property
    def has_constraints(self):
        return self.is_core_type and (self.min_length is not None or self.max_length is not None)

    @property
    def is_constructor(self) -> bool:
        return self.import_type is not None

    @property
    def is_vector_type(self) -> bool:
        return "list" in self.type

    @property
    def is_core_type(self):
        return self.type in core_types

    @property
    def doc_type(self) -> str:
        if self.is_vector_type:
            return f"(:obj:`{self.type}`)"

        return f"(:class:`{self.type}`)"

    @property
    def import_type(self) -> typing.Optional[str]:
        if self.type in core_types:
            return None

        if self.is_vector_type:
            inner_vector_type = list_type_regex.match(self.type).group('type')

            if inner_vector_type in core_types:
                return None

            return inner_vector_type

        return self.type

    @property
    def optional_type(self):
        # Workaround for nullable vector types items https://github.com/tdlib/td/issues/1016#issuecomment-618959102
        if self.is_vector_type:
            return re.sub(r"(.*list\[)(\w+)(].*)", r'\1typing.Optional[\2]\3', self.type)

        return f"typing.Optional[{self.type}]"


class Dependency(BaseModel):
    name: str
    type: str

    def __eq__(self, other):
        if not isinstance(other, Dependency):
            return False

        return self.name == other.name and self.type == other.type

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return str.__hash__(f"{self.name}.{self.type}")


class BaseEntity(BaseType):
    doc: str = ""
    parameters: list[Parameter] = []

    @property
    def has_shadow_names(self) -> bool:
        return any(p.name[-1] == '_' for p in self.parameters)

    @property
    def is_function(self) -> bool:
        return isinstance(self, Method)

    @property
    def is_constructor(self) -> bool:
        return isinstance(self, ConstructorShort)

    @property
    def dependencies(self) -> list[Dependency]:
        return []


class ConstructorShort(BaseEntity):
    is_abstract: bool = False


class Constructor(ConstructorShort):
    subclasses: list[Constructor] = []
    cross_deps: list[Constructor] = []
    parent_class: typing.Optional[ConstructorShort] = None

    @property
    def has_shadow_names(self) -> bool:
        for s in self.subclasses:
            for p in s.parameters:
                if "_" in p.name:
                    return True

        for cd in self.cross_deps:
            for p in cd.parameters:
                if "_" in p.name:
                    return True

        return super(Constructor, self).has_shadow_names

    @property
    def dependencies(self) -> list[Dependency]:
        deps = set()
        cross_deps = [c.name for c in self.cross_deps]

        for p in self.parameters:
            if bool(p.import_type) and not bool(p.import_type) in cross_deps:
                deps.add(Dependency(name=snake_case(p.import_type), type=p.import_type))

        for subclass in self.subclasses:
            for p in subclass.parameters:
                if (
                        bool(p.import_type)
                        and p.import_type != self.uf_name
                        and upper_first(p.import_type) not in cross_deps
                ):
                    deps.add(Dependency(
                        name=snake_case(p.import_type),
                        type=p.import_type
                    ))

        for dep in self.cross_deps:
            for p in dep.parameters:
                if bool(p.import_type) and p.import_type != self.uf_name:
                    deps.add(Dependency(
                        name=snake_case(p.import_type),
                        type=p.import_type
                    ))

        return list(sorted(deps, key=lambda x: x.name))


class Method(BaseEntity):
    return_type: typing.Union[str, Constructor]

    @validator('return_type', pre=True)
    def _convert_return_type(cls, return_type: typing.Union[str, Constructor]) -> typing.Union[str, Constructor]:
        if not return_type:
            return ""

        if isinstance(return_type, str):
            if return_type in core_types:
                return core_types[return_type]
            else:
                raise ValueError

        return return_type

    @property
    def return_type_str(self) -> str:
        return self.return_type if isinstance(self.return_type, str) else self.return_type.uf_name

    @property
    def dependencies(self) -> list[Dependency]:
        deps = set()

        for p in self.parameters:
            if p.import_type is not None:
                deps.add(Dependency(
                    name=snake_case(p.import_type),
                    type=p.import_type
                ))

        return list(sorted(deps, key=lambda x: x.name))


BaseEntity.update_forward_refs()
Constructor.update_forward_refs()



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class MessageSender(BaseObject):
    """
    Contains information about the sender of a message
    
    """

    ID: str = Field("messageSender", alias="@type")


class MessageSenderChat(MessageSender):
    """
    The message was sent on behalf of a chat
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat that sent the message
        
    """

    ID: str = Field("messageSenderChat", alias="@type")
    chat_id: int

    @staticmethod
    def read(q: dict) -> MessageSenderChat:
        return MessageSenderChat.construct(**q)


class MessageSenderUser(MessageSender):
    """
    The message was sent by a known user
    
    Params:
        user_id (:class:`int`)
            Identifier of the user that sent the message
        
    """

    ID: str = Field("messageSenderUser", alias="@type")
    user_id: int

    @staticmethod
    def read(q: dict) -> MessageSenderUser:
        return MessageSenderUser.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TestNetwork(BaseObject):
    """
    Sends a simple network request to the Telegram servers; for testing only. Can be called before authorization
    
    """

    ID: str = Field("testNetwork", alias="@type")

    @staticmethod
    def read(q: dict) -> TestNetwork:
        return TestNetwork.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ResetAllNotificationSettings(BaseObject):
    """
    Resets all notification settings to their default values. By default, all chats are unmuted, the sound is set to "default" and message previews are shown
    
    """

    ID: str = Field("resetAllNotificationSettings", alias="@type")

    @staticmethod
    def read(q: dict) -> ResetAllNotificationSettings:
        return ResetAllNotificationSettings.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .text_entity import TextEntity
from ..base_object import BaseObject


class FormattedText(BaseObject):
    """
    A text with some entities
    
    Params:
        text (:class:`str`)
            The text
        
        entities (:obj:`list[TextEntity]`)
            Entities contained in the text. Entities can be nested, but must not mutually intersect with each other. Pre, Code and PreCode entities can't contain other entities. Bold, Italic, Underline and Strikethrough entities can contain and to be contained in all other entities. All other entities can't contain each other
        
    """

    ID: str = Field("formattedText", alias="@type")
    text: str
    entities: list[TextEntity]

    @staticmethod
    def read(q: dict) -> FormattedText:
        return FormattedText.construct(**q)



import re

from setuptools import find_packages, setup

with open("README.md") as file:
    read_me_description = file.read()

with open("requirements.txt") as r:
    requirements = [i.strip() for i in r]

with open("aiotdlib/__init__.py", encoding="utf-8") as f:
    version = re.findall(r"__version__ = \"(.+)\"", f.read())[0]

setup(
    name="aiotdlib",
    version=version,
    license='MIT',
    author="Pylakey",
    author_email="pylakey@protonmail.com",
    description="Python asyncio wrapper for TDLib",
    long_description=read_me_description,
    long_description_content_type="text/markdown",
    packages=find_packages(
        exclude=('generator',)
    ),
    classifiers=[
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=requirements,
    python_requires='>=3.9',
    include_package_data=True,
)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_member_status import ChatMemberStatus
from ..base_object import BaseObject


class Supergroup(BaseObject):
    """
    Represents a supergroup or channel with zero or more members (subscribers in the case of channels). From the point of view of the system, a channel is a special kind of a supergroup: only administrators can post and see the list of members, and posts from all administrators use the name and photo of the channel instead of individual names and profile photos. Unlike supergroups, channels can have an unlimited number of subscribers
    
    Params:
        id (:class:`int`)
            Supergroup or channel identifier
        
        username (:class:`str`)
            Username of the supergroup or channel; empty for private supergroups or channels
        
        date (:class:`int`)
            Point in time (Unix timestamp) when the current user joined, or the point in time when the supergroup or channel was created, in case the user is not a member
        
        status (:class:`ChatMemberStatus`)
            Status of the current user in the supergroup or channel; custom title will be always empty
        
        member_count (:class:`int`)
            Number of members in the supergroup or channel; 0 if unknown. Currently it is guaranteed to be known only if the supergroup or channel was received through searchPublicChats, searchChatsNearby, getInactiveSupergroupChats, getSuitableDiscussionChats, getGroupsInCommon, or getUserPrivacySettingRules
        
        has_linked_chat (:class:`bool`)
            True, if the channel has a discussion group, or the supergroup is the designated discussion group for a channel
        
        has_location (:class:`bool`)
            True, if the supergroup is connected to a location, i.e. the supergroup is a location-based supergroup
        
        sign_messages (:class:`bool`)
            True, if messages sent to the channel should contain information about the sender. This field is only applicable to channels
        
        is_slow_mode_enabled (:class:`bool`)
            True, if the slow mode is enabled in the supergroup
        
        is_channel (:class:`bool`)
            True, if the supergroup is a channel
        
        is_broadcast_group (:class:`bool`)
            True, if the supergroup is a broadcast group, i.e. only administrators can send messages and there is no limit on number of members
        
        is_verified (:class:`bool`)
            True, if the supergroup or channel is verified
        
        restriction_reason (:class:`str`)
            If non-empty, contains a human-readable description of the reason why access to this supergroup or channel must be restricted
        
        is_scam (:class:`bool`)
            True, if many users reported this supergroup or channel as a scam
        
        is_fake (:class:`bool`)
            True, if many users reported this supergroup or channel as a fake account
        
    """

    ID: str = Field("supergroup", alias="@type")
    id: int
    username: str
    date: int
    status: ChatMemberStatus
    member_count: int
    has_linked_chat: bool
    has_location: bool
    sign_messages: bool
    is_slow_mode_enabled: bool
    is_channel: bool
    is_broadcast_group: bool
    is_verified: bool
    restriction_reason: str
    is_scam: bool
    is_fake: bool

    @staticmethod
    def read(q: dict) -> Supergroup:
        return Supergroup.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .page_block_horizontal_alignment import PageBlockHorizontalAlignment
from .page_block_vertical_alignment import PageBlockVerticalAlignment
from .rich_text import RichText
from ..base_object import BaseObject


class PageBlockTableCell(BaseObject):
    """
    Represents a cell of a table
    
    Params:
        text (:class:`RichText`)
            Cell text; may be null. If the text is null, then the cell should be invisible
        
        is_header (:class:`bool`)
            True, if it is a header cell
        
        colspan (:class:`int`)
            The number of columns the cell should span
        
        rowspan (:class:`int`)
            The number of rows the cell should span
        
        align (:class:`PageBlockHorizontalAlignment`)
            Horizontal cell content alignment
        
        valign (:class:`PageBlockVerticalAlignment`)
            Vertical cell content alignment
        
    """

    ID: str = Field("pageBlockTableCell", alias="@type")
    text: typing.Optional[RichText] = None
    is_header: bool
    colspan: int
    rowspan: int
    align: PageBlockHorizontalAlignment
    valign: PageBlockVerticalAlignment

    @staticmethod
    def read(q: dict) -> PageBlockTableCell:
        return PageBlockTableCell.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetStatisticalGraph(BaseObject):
    """
    Loads an asynchronous or a zoomed in statistical graph
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        token (:class:`str`)
            The token for graph loading
        
        x (:class:`int`)
            X-value for zoomed in graph or 0 otherwise
        
    """

    ID: str = Field("getStatisticalGraph", alias="@type")
    chat_id: int
    token: str
    x: int

    @staticmethod
    def read(q: dict) -> GetStatisticalGraph:
        return GetStatisticalGraph.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .address import Address
from .input_identity_document import InputIdentityDocument
from .input_personal_document import InputPersonalDocument
from .personal_details import PersonalDetails
from ..base_object import BaseObject


class InputPassportElement(BaseObject):
    """
    Contains information about a Telegram Passport element to be saved
    
    """

    ID: str = Field("inputPassportElement", alias="@type")


class InputPassportElementAddress(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's address
    
    Params:
        address (:class:`Address`)
            The address to be saved
        
    """

    ID: str = Field("inputPassportElementAddress", alias="@type")
    address: Address

    @staticmethod
    def read(q: dict) -> InputPassportElementAddress:
        return InputPassportElementAddress.construct(**q)


class InputPassportElementBankStatement(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's bank statement
    
    Params:
        bank_statement (:class:`InputPersonalDocument`)
            The bank statement to be saved
        
    """

    ID: str = Field("inputPassportElementBankStatement", alias="@type")
    bank_statement: InputPersonalDocument

    @staticmethod
    def read(q: dict) -> InputPassportElementBankStatement:
        return InputPassportElementBankStatement.construct(**q)


class InputPassportElementDriverLicense(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's driver license
    
    Params:
        driver_license (:class:`InputIdentityDocument`)
            The driver license to be saved
        
    """

    ID: str = Field("inputPassportElementDriverLicense", alias="@type")
    driver_license: InputIdentityDocument

    @staticmethod
    def read(q: dict) -> InputPassportElementDriverLicense:
        return InputPassportElementDriverLicense.construct(**q)


class InputPassportElementEmailAddress(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's email address
    
    Params:
        email_address (:class:`str`)
            The email address to be saved
        
    """

    ID: str = Field("inputPassportElementEmailAddress", alias="@type")
    email_address: str

    @staticmethod
    def read(q: dict) -> InputPassportElementEmailAddress:
        return InputPassportElementEmailAddress.construct(**q)


class InputPassportElementIdentityCard(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's identity card
    
    Params:
        identity_card (:class:`InputIdentityDocument`)
            The identity card to be saved
        
    """

    ID: str = Field("inputPassportElementIdentityCard", alias="@type")
    identity_card: InputIdentityDocument

    @staticmethod
    def read(q: dict) -> InputPassportElementIdentityCard:
        return InputPassportElementIdentityCard.construct(**q)


class InputPassportElementInternalPassport(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's internal passport
    
    Params:
        internal_passport (:class:`InputIdentityDocument`)
            The internal passport to be saved
        
    """

    ID: str = Field("inputPassportElementInternalPassport", alias="@type")
    internal_passport: InputIdentityDocument

    @staticmethod
    def read(q: dict) -> InputPassportElementInternalPassport:
        return InputPassportElementInternalPassport.construct(**q)


class InputPassportElementPassport(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's passport
    
    Params:
        passport (:class:`InputIdentityDocument`)
            The passport to be saved
        
    """

    ID: str = Field("inputPassportElementPassport", alias="@type")
    passport: InputIdentityDocument

    @staticmethod
    def read(q: dict) -> InputPassportElementPassport:
        return InputPassportElementPassport.construct(**q)


class InputPassportElementPassportRegistration(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's passport registration
    
    Params:
        passport_registration (:class:`InputPersonalDocument`)
            The passport registration page to be saved
        
    """

    ID: str = Field("inputPassportElementPassportRegistration", alias="@type")
    passport_registration: InputPersonalDocument

    @staticmethod
    def read(q: dict) -> InputPassportElementPassportRegistration:
        return InputPassportElementPassportRegistration.construct(**q)


class InputPassportElementPersonalDetails(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's personal details
    
    Params:
        personal_details (:class:`PersonalDetails`)
            Personal details of the user
        
    """

    ID: str = Field("inputPassportElementPersonalDetails", alias="@type")
    personal_details: PersonalDetails

    @staticmethod
    def read(q: dict) -> InputPassportElementPersonalDetails:
        return InputPassportElementPersonalDetails.construct(**q)


class InputPassportElementPhoneNumber(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's phone number
    
    Params:
        phone_number (:class:`str`)
            The phone number to be saved
        
    """

    ID: str = Field("inputPassportElementPhoneNumber", alias="@type")
    phone_number: str

    @staticmethod
    def read(q: dict) -> InputPassportElementPhoneNumber:
        return InputPassportElementPhoneNumber.construct(**q)


class InputPassportElementRentalAgreement(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's rental agreement
    
    Params:
        rental_agreement (:class:`InputPersonalDocument`)
            The rental agreement to be saved
        
    """

    ID: str = Field("inputPassportElementRentalAgreement", alias="@type")
    rental_agreement: InputPersonalDocument

    @staticmethod
    def read(q: dict) -> InputPassportElementRentalAgreement:
        return InputPassportElementRentalAgreement.construct(**q)


class InputPassportElementTemporaryRegistration(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's temporary registration
    
    Params:
        temporary_registration (:class:`InputPersonalDocument`)
            The temporary registration document to be saved
        
    """

    ID: str = Field("inputPassportElementTemporaryRegistration", alias="@type")
    temporary_registration: InputPersonalDocument

    @staticmethod
    def read(q: dict) -> InputPassportElementTemporaryRegistration:
        return InputPassportElementTemporaryRegistration.construct(**q)


class InputPassportElementUtilityBill(InputPassportElement):
    """
    A Telegram Passport element to be saved containing the user's utility bill
    
    Params:
        utility_bill (:class:`InputPersonalDocument`)
            The utility bill to be saved
        
    """

    ID: str = Field("inputPassportElementUtilityBill", alias="@type")
    utility_bill: InputPersonalDocument

    @staticmethod
    def read(q: dict) -> InputPassportElementUtilityBill:
        return InputPassportElementUtilityBill.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import OptionValue


class SetOption(BaseObject):
    """
    Sets the value of an option. (Check the list of available options on https://core.telegram.org/tdlib/options.) Only writable options can be set. Can be called before authorization
    
    Params:
        name (:class:`str`)
            The name of the option
        
        value (:class:`OptionValue`)
            The new value of the option
        
    """

    ID: str = Field("setOption", alias="@type")
    name: str
    value: OptionValue

    @staticmethod
    def read(q: dict) -> SetOption:
        return SetOption.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ClearRecentStickers(BaseObject):
    """
    Clears the list of recently used stickers
    
    Params:
        is_attached (:class:`bool`)
            Pass true to clear the list of stickers recently attached to photo or video files; pass false to clear the list of recently sent stickers
        
    """

    ID: str = Field("clearRecentStickers", alias="@type")
    is_attached: bool

    @staticmethod
    def read(q: dict) -> ClearRecentStickers:
        return ClearRecentStickers.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class KeyboardButtonType(BaseObject):
    """
    Describes a keyboard button type
    
    """

    ID: str = Field("keyboardButtonType", alias="@type")


class KeyboardButtonTypeRequestLocation(KeyboardButtonType):
    """
    A button that sends the user's location when pressed; available only in private chats
    
    """

    ID: str = Field("keyboardButtonTypeRequestLocation", alias="@type")

    @staticmethod
    def read(q: dict) -> KeyboardButtonTypeRequestLocation:
        return KeyboardButtonTypeRequestLocation.construct(**q)


class KeyboardButtonTypeRequestPhoneNumber(KeyboardButtonType):
    """
    A button that sends the user's phone number when pressed; available only in private chats
    
    """

    ID: str = Field("keyboardButtonTypeRequestPhoneNumber", alias="@type")

    @staticmethod
    def read(q: dict) -> KeyboardButtonTypeRequestPhoneNumber:
        return KeyboardButtonTypeRequestPhoneNumber.construct(**q)


class KeyboardButtonTypeRequestPoll(KeyboardButtonType):
    """
    A button that allows the user to create and send a poll when pressed; available only in private chats
    
    Params:
        force_regular (:class:`bool`)
            If true, only regular polls must be allowed to create
        
        force_quiz (:class:`bool`)
            If true, only polls in quiz mode must be allowed to create
        
    """

    ID: str = Field("keyboardButtonTypeRequestPoll", alias="@type")
    force_regular: bool
    force_quiz: bool

    @staticmethod
    def read(q: dict) -> KeyboardButtonTypeRequestPoll:
        return KeyboardButtonTypeRequestPoll.construct(**q)


class KeyboardButtonTypeText(KeyboardButtonType):
    """
    A simple button, with text that should be sent when the button is pressed
    
    """

    ID: str = Field("keyboardButtonTypeText", alias="@type")

    @staticmethod
    def read(q: dict) -> KeyboardButtonTypeText:
        return KeyboardButtonTypeText.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetLocalizationTargetInfo(BaseObject):
    """
    Returns information about the current localization target. This is an offline request if only_local is true. Can be called before authorization
    
    Params:
        only_local (:class:`bool`)
            If true, returns only locally available information without sending network requests
        
    """

    ID: str = Field("getLocalizationTargetInfo", alias="@type")
    only_local: bool

    @staticmethod
    def read(q: dict) -> GetLocalizationTargetInfo:
        return GetLocalizationTargetInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetSupergroupStickerSet(BaseObject):
    """
    Changes the sticker set of a supergroup; requires can_change_info administrator right
    
    Params:
        supergroup_id (:class:`int`)
            Identifier of the supergroup
        
        sticker_set_id (:class:`int`)
            New value of the supergroup sticker set identifier. Use 0 to remove the supergroup sticker set
        
    """

    ID: str = Field("setSupergroupStickerSet", alias="@type")
    supergroup_id: int
    sticker_set_id: int

    @staticmethod
    def read(q: dict) -> SetSupergroupStickerSet:
        return SetSupergroupStickerSet.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatList


class SetPinnedChats(BaseObject):
    """
    Changes the order of pinned chats
    
    Params:
        chat_list (:class:`ChatList`)
            Chat list in which to change the order of pinned chats
        
        chat_ids (:obj:`list[int]`)
            The new list of pinned chats
        
    """

    ID: str = Field("setPinnedChats", alias="@type")
    chat_list: ChatList
    chat_ids: list[int]

    @staticmethod
    def read(q: dict) -> SetPinnedChats:
        return SetPinnedChats.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputChatPhoto


class SetChatPhoto(BaseObject):
    """
    Changes the photo of a chat. Supported only for basic groups, supergroups and channels. Requires can_change_info administrator right
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        photo (:class:`InputChatPhoto`)
            New chat photo. Pass null to delete the chat photo
        
    """

    ID: str = Field("setChatPhoto", alias="@type")
    chat_id: int
    photo: InputChatPhoto

    @staticmethod
    def read(q: dict) -> SetChatPhoto:
        return SetChatPhoto.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatList


class AddChatToList(BaseObject):
    """
    Adds a chat to a chat list. A chat can't be simultaneously in Main and Archive chat lists, so it is automatically removed from another one if needed
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        chat_list (:class:`ChatList`)
            The chat list. Use getChatListsToAddChat to get suitable chat lists
        
    """

    ID: str = Field("addChatToList", alias="@type")
    chat_id: int
    chat_list: ChatList

    @staticmethod
    def read(q: dict) -> AddChatToList:
        return AddChatToList.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .bank_card_action_open_url import BankCardActionOpenUrl
from ..base_object import BaseObject


class BankCardInfo(BaseObject):
    """
    Information about a bank card
    
    Params:
        title (:class:`str`)
            Title of the bank card description
        
        actions (:obj:`list[BankCardActionOpenUrl]`)
            Actions that can be done with the bank card number
        
    """

    ID: str = Field("bankCardInfo", alias="@type")
    title: str
    actions: list[BankCardActionOpenUrl]

    @staticmethod
    def read(q: dict) -> BankCardInfo:
        return BankCardInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from ..base_object import BaseObject
from ..types import DraftMessage


class SetChatDraftMessage(BaseObject):
    """
    Changes the draft message in a chat
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        message_thread_id (:class:`int`)
            If not 0, a message thread identifier in which the draft was changed
        
        draft_message (:class:`DraftMessage`)
            New draft message; may be null
        
    """

    ID: str = Field("setChatDraftMessage", alias="@type")
    chat_id: int
    message_thread_id: int
    draft_message: typing.Optional[DraftMessage] = None

    @staticmethod
    def read(q: dict) -> SetChatDraftMessage:
        return SetChatDraftMessage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetChatInviteLink(BaseObject):
    """
    Returns information about an invite link. Requires administrator privileges and can_invite_users right in the chat to get own links and owner privileges to get other links
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        invite_link (:class:`str`)
            Invite link to get
        
    """

    ID: str = Field("getChatInviteLink", alias="@type")
    chat_id: int
    invite_link: str

    @staticmethod
    def read(q: dict) -> GetChatInviteLink:
        return GetChatInviteLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchStickerSets(BaseObject):
    """
    Searches for ordinary sticker sets by looking for specified query in their title and name. Excludes installed sticker sets from the results
    
    Params:
        query (:class:`str`)
            Query to search for
        
    """

    ID: str = Field("searchStickerSets", alias="@type")
    query: str

    @staticmethod
    def read(q: dict) -> SearchStickerSets:
        return SearchStickerSets.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GroupCallPayloadFingerprint(BaseObject):
    """
    Describes a payload fingerprint for interaction with tgcalls
    
    Params:
        hash_ (:class:`str`)
            Value of the field hash
        
        setup (:class:`str`)
            Value of the field setup
        
        fingerprint (:class:`str`)
            Value of the field fingerprint
        
    """

    ID: str = Field("groupCallPayloadFingerprint", alias="@type")
    hash_: str = Field(..., alias='hash')
    setup: str
    fingerprint: str

    @staticmethod
    def read(q: dict) -> GroupCallPayloadFingerprint:
        return GroupCallPayloadFingerprint.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ReorderChatFilters(BaseObject):
    """
    Changes the order of chat filters
    
    Params:
        chat_filter_ids (:obj:`list[int]`)
            Identifiers of chat filters in the new correct order
        
    """

    ID: str = Field("reorderChatFilters", alias="@type")
    chat_filter_ids: list[int]

    @staticmethod
    def read(q: dict) -> ReorderChatFilters:
        return ReorderChatFilters.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AccountTtl(BaseObject):
    """
    Contains information about the period of inactivity after which the current user's account will automatically be deleted
    
    Params:
        days (:class:`int`)
            Number of days of inactivity before the account will be flagged for deletion; should range from 30-366 days
        
    """

    ID: str = Field("accountTtl", alias="@type")
    days: int

    @staticmethod
    def read(q: dict) -> AccountTtl:
        return AccountTtl.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .passport_element_type import PassportElementType
from ..base_object import BaseObject


class PassportSuitableElement(BaseObject):
    """
    Contains information about a Telegram Passport element that was requested by a service
    
    Params:
        type_ (:class:`PassportElementType`)
            Type of the element
        
        is_selfie_required (:class:`bool`)
            True, if a selfie is required with the identity document
        
        is_translation_required (:class:`bool`)
            True, if a certified English translation is required with the document
        
        is_native_name_required (:class:`bool`)
            True, if personal details must include the user's name in the language of their country of residence
        
    """

    ID: str = Field("passportSuitableElement", alias="@type")
    type_: PassportElementType = Field(..., alias='type')
    is_selfie_required: bool
    is_translation_required: bool
    is_native_name_required: bool

    @staticmethod
    def read(q: dict) -> PassportSuitableElement:
        return PassportSuitableElement.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AddCustomServerLanguagePack(BaseObject):
    """
    Adds a custom server language pack to the list of installed language packs in current localization target. Can be called before authorization
    
    Params:
        language_pack_id (:class:`str`)
            Identifier of a language pack to be added; may be different from a name that is used in an "https://t.me/setlanguage/" link
        
    """

    ID: str = Field("addCustomServerLanguagePack", alias="@type")
    language_pack_id: str

    @staticmethod
    def read(q: dict) -> AddCustomServerLanguagePack:
        return AddCustomServerLanguagePack.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputMessageContent, ReplyMarkup


class EditMessageMedia(BaseObject):
    """
    Edits the content of a message with an animation, an audio, a document, a photo or a video. The media in the message can't be replaced if the message was set to self-destruct. Media can't be replaced by self-destructing media. Media in an album can be edited only to contain a photo or a video. Returns the edited message after the edit is completed on the server side
    
    Params:
        chat_id (:class:`int`)
            The chat the message belongs to
        
        message_id (:class:`int`)
            Identifier of the message
        
        reply_markup (:class:`ReplyMarkup`)
            The new message reply markup; for bots only
        
        input_message_content (:class:`InputMessageContent`)
            New content of the message. Must be one of the following types: InputMessageAnimation, InputMessageAudio, InputMessageDocument, InputMessagePhoto or InputMessageVideo
        
    """

    ID: str = Field("editMessageMedia", alias="@type")
    chat_id: int
    message_id: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> EditMessageMedia:
        return EditMessageMedia.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .formatted_text import FormattedText
from ..base_object import BaseObject


class TermsOfService(BaseObject):
    """
    Contains Telegram terms of service
    
    Params:
        text (:class:`FormattedText`)
            Text of the terms of service
        
        min_user_age (:class:`int`)
            The minimum age of a user to be able to accept the terms; 0 if any
        
        show_popup (:class:`bool`)
            True, if a blocking popup with terms of service must be shown to the user
        
    """

    ID: str = Field("termsOfService", alias="@type")
    text: FormattedText
    min_user_age: int
    show_popup: bool

    @staticmethod
    def read(q: dict) -> TermsOfService:
        return TermsOfService.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SuggestedAction(BaseObject):
    """
    Describes an action suggested to the current user
    
    """

    ID: str = Field("suggestedAction", alias="@type")


class SuggestedActionCheckPhoneNumber(SuggestedAction):
    """
    Suggests the user to check authorization phone number and change the phone number if it is inaccessible
    
    """

    ID: str = Field("suggestedActionCheckPhoneNumber", alias="@type")

    @staticmethod
    def read(q: dict) -> SuggestedActionCheckPhoneNumber:
        return SuggestedActionCheckPhoneNumber.construct(**q)


class SuggestedActionConvertToBroadcastGroup(SuggestedAction):
    """
    Suggests the user to convert specified supergroup to a broadcast group
    
    Params:
        supergroup_id (:class:`int`)
            Supergroup identifier
        
    """

    ID: str = Field("suggestedActionConvertToBroadcastGroup", alias="@type")
    supergroup_id: int

    @staticmethod
    def read(q: dict) -> SuggestedActionConvertToBroadcastGroup:
        return SuggestedActionConvertToBroadcastGroup.construct(**q)


class SuggestedActionEnableArchiveAndMuteNewChats(SuggestedAction):
    """
    Suggests the user to enable "archive_and_mute_new_chats_from_unknown_users" option
    
    """

    ID: str = Field("suggestedActionEnableArchiveAndMuteNewChats", alias="@type")

    @staticmethod
    def read(q: dict) -> SuggestedActionEnableArchiveAndMuteNewChats:
        return SuggestedActionEnableArchiveAndMuteNewChats.construct(**q)


class SuggestedActionSeeTicksHint(SuggestedAction):
    """
    Suggests the user to see a hint about meaning of one and two ticks on sent message
    
    """

    ID: str = Field("suggestedActionSeeTicksHint", alias="@type")

    @staticmethod
    def read(q: dict) -> SuggestedActionSeeTicksHint:
        return SuggestedActionSeeTicksHint.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import Error


class FinishFileGeneration(BaseObject):
    """
    Finishes the file generation
    
    Params:
        generation_id (:class:`int`)
            The identifier of the generation process
        
        error (:class:`Error`)
            If set, means that file generation has failed and should be terminated
        
    """

    ID: str = Field("finishFileGeneration", alias="@type")
    generation_id: int
    error: Error

    @staticmethod
    def read(q: dict) -> FinishFileGeneration:
        return FinishFileGeneration.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .dated_file import DatedFile
from ..base_object import BaseObject


class PersonalDocument(BaseObject):
    """
    A personal document, containing some information about a user
    
    Params:
        files (:obj:`list[DatedFile]`)
            List of files containing the pages of the document
        
        translation (:obj:`list[DatedFile]`)
            List of files containing a certified English translation of the document
        
    """

    ID: str = Field("personalDocument", alias="@type")
    files: list[DatedFile]
    translation: list[DatedFile]

    @staticmethod
    def read(q: dict) -> PersonalDocument:
        return PersonalDocument.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .invoice import Invoice
from .order_info import OrderInfo
from .payments_provider_stripe import PaymentsProviderStripe
from .saved_credentials import SavedCredentials
from ..base_object import BaseObject


class PaymentForm(BaseObject):
    """
    Contains information about an invoice payment form
    
    Params:
        invoice (:class:`Invoice`)
            Full information of the invoice
        
        url (:class:`str`)
            Payment form URL
        
        payments_provider (:class:`PaymentsProviderStripe`)
            Contains information about the payment provider, if available, to support it natively without the need for opening the URL; may be null
        
        saved_order_info (:class:`OrderInfo`)
            Saved server-side order information; may be null
        
        saved_credentials (:class:`SavedCredentials`)
            Contains information about saved card credentials; may be null
        
        can_save_credentials (:class:`bool`)
            True, if the user can choose to save credentials
        
        need_password (:class:`bool`)
            True, if the user will be able to save credentials protected by a password they set up
        
    """

    ID: str = Field("paymentForm", alias="@type")
    invoice: Invoice
    url: str
    payments_provider: typing.Optional[PaymentsProviderStripe] = None
    saved_order_info: typing.Optional[OrderInfo] = None
    saved_credentials: typing.Optional[SavedCredentials] = None
    can_save_credentials: bool
    need_password: bool

    @staticmethod
    def read(q: dict) -> PaymentForm:
        return PaymentForm.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class RemoveRecentHashtag(BaseObject):
    """
    Removes a hashtag from the list of recently used hashtags
    
    Params:
        hashtag (:class:`str`)
            Hashtag to delete
        
    """

    ID: str = Field("removeRecentHashtag", alias="@type")
    hashtag: str

    @staticmethod
    def read(q: dict) -> RemoveRecentHashtag:
        return RemoveRecentHashtag.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SearchBackground(BaseObject):
    """
    Searches for a background by its name
    
    Params:
        name (:class:`str`)
            The name of the background
        
    """

    ID: str = Field("searchBackground", alias="@type")
    name: str

    @staticmethod
    def read(q: dict) -> SearchBackground:
        return SearchBackground.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputFile


class AddRecentSticker(BaseObject):
    """
    Manually adds a new sticker to the list of recently used stickers. The new sticker is added to the top of the list. If the sticker was already in the list, it is removed from the list first. Only stickers belonging to a sticker set can be added to this list
    
    Params:
        is_attached (:class:`bool`)
            Pass true to add the sticker to the list of stickers recently attached to photo or video files; pass false to add the sticker to the list of recently sent stickers
        
        sticker (:class:`InputFile`)
            Sticker file to add
        
    """

    ID: str = Field("addRecentSticker", alias="@type")
    is_attached: bool
    sticker: InputFile

    @staticmethod
    def read(q: dict) -> AddRecentSticker:
        return AddRecentSticker.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetInlineGameHighScores(BaseObject):
    """
    Returns game high scores and some part of the high score table in the range of the specified user; for bots only
    
    Params:
        inline_message_id (:class:`str`)
            Inline message identifier
        
        user_id (:class:`int`)
            User identifier
        
    """

    ID: str = Field("getInlineGameHighScores", alias="@type")
    inline_message_id: str
    user_id: int

    @staticmethod
    def read(q: dict) -> GetInlineGameHighScores:
        return GetInlineGameHighScores.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckAuthenticationBotToken(BaseObject):
    """
    Checks the authentication token of a bot; to log in as a bot. Works only when the current authorization state is authorizationStateWaitPhoneNumber. Can be used instead of setAuthenticationPhoneNumber and checkAuthenticationCode to log in
    
    Params:
        token (:class:`str`)
            The bot token
        
    """

    ID: str = Field("checkAuthenticationBotToken", alias="@type")
    token: str

    @staticmethod
    def read(q: dict) -> CheckAuthenticationBotToken:
        return CheckAuthenticationBotToken.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .passport_required_element import PassportRequiredElement
from ..base_object import BaseObject


class PassportAuthorizationForm(BaseObject):
    """
    Contains information about a Telegram Passport authorization form that was requested
    
    Params:
        id (:class:`int`)
            Unique identifier of the authorization form
        
        required_elements (:obj:`list[PassportRequiredElement]`)
            Information about the Telegram Passport elements that must be provided to complete the form
        
        privacy_policy_url (:class:`str`)
            URL for the privacy policy of the service; may be empty
        
    """

    ID: str = Field("passportAuthorizationForm", alias="@type")
    id: int
    required_elements: list[PassportRequiredElement]
    privacy_policy_url: str

    @staticmethod
    def read(q: dict) -> PassportAuthorizationForm:
        return PassportAuthorizationForm.construct(**q)
